Examples
========

:ref:`code_examples` code.

List of examples from the beampy.examples module.

.. automodule:: beampy.examples
   :members:
   :undoc-members:
   :show-inheritance:

:download:`Gaussian beam definition <results/def_gauss_beam.pdf>`

:download:`Guide definition over x <results/def_gauss_guide.pdf>`


:download:`Array of guides <results/guide_array.pdf>`

:download:`Curved guides <results/guide_curved.pdf>`


:download:`Example with field real part <results/stability_field_real.pdf>`

:download:`Example with field imag part <results/stability_field_imag.pdf>`

:download:`Example with power <results/index_order_impact.pdf>`


:download:`Example with Kerr <results/kerr_order_impact.pdf>`

:download:`Example with extreme Kerr <results/Impact_order_kerr_limit.pdf>`
